package lib

import (
	"log"
	"testing"
)

const simplePackageJSON = `
{
    "name": "test",
    "version": "1.0.0",
    "scripts": { "test": "echo testing", "build": "echo hello > world.txt" },
    "keywords": [],
    "license": "UNLICENSED",
    "dependencies": { "globby": "1.0.0" },
    "devDependencies": { "mocha": "*" }
}

`

func init() {
	log.SetFlags(log.Lshortfile)
}

func TestBuildDependencyTree(t *testing.T) {
	tests := []struct {
		name     string
		args     PackageJSON
		depCount int
		want     map[string]Dependency
		wantErr  bool
	}{
		{
			name:     "globby",
			depCount: 13,
			wantErr:  false,
			args: PackageJSON{
				Name: "globby",
				Dependencies: map[string]string{
					"array-differ": "^1.0.0",
					"array-union":  "^1.0.1",
					"async":        "^0.9.0",
					"glob":         "^4.0.2",
				},
			},
		},
		{
			name:     "webpack test",
			depCount: 13,
			wantErr:  false,
			args: PackageJSON{
				Name: "webpack",
				Dependencies: map[string]string{
					"webpack": "*",
				},
			},
		},

		{
			name:     "react test",
			depCount: 13,
			wantErr:  false,
			args: PackageJSON{
				Name: "website",
				Dependencies: map[string]string{
					"react": "16",
				},
			},
		},
	}

	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			got, err := BuildDependencyTree(tt.args)
			if (err != nil) != tt.wantErr {
				t.Errorf("BuildDependencyTree() error = %v, wantErr %v", err, tt.wantErr)
				return
			}

			t.Logf("%+v", got)

			if len(got.Dependencies) != tt.depCount {
				t.Errorf("BuildDependencyTree() = %v, want %v", len(got.Dependencies), tt.depCount)
				return
			}
		})
	}
}
